<?php

global $newuser_text;
$newuser_text = array (

'registernewuser' =>  'Neuen Benutzer registrieren',
'requiredfields'  =>  'Notwendige Felder sind gekennzeichnet:',
'username'        =>  'Benutzername',
'password'        =>  'Passwort',
'confirmpass'     =>  'Passwort bestätigen',
'realname'        =>  'Realname',
'emailaddress'    =>  'E-Mail',
'jabberid'        =>  'Jabber ID',
'notifications'   =>  'Benachrichtigungen',
'none'            =>  'Keine',
'email'           =>  'E-Mail',
'jabber'          =>  'Jabber',
'registeraccount' =>  'Benutzer registrieren',

// New in 0.9.7
'globalgroup'     =>  'Globale Gruppe',

);
?>
